==> open-xchange-subscribe_7.0.1.orig.tar.bz2: open-xchange-subscribe-7.0.1/com.openexchange.subscribe.json/src/com/openexchange/subscribe/json/SubscriptionServlet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.json;

import javax.servlet.http.HttpServletRequest;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.MultipleAdapterServlet;
import com.openexchange.multiple.MultipleHandler;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link SubscriptionServlet}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 *
 */
public class SubscriptionServlet extends MultipleAdapterServlet {

    private static SubscriptionMultipleFactory multipleFactory = null;

    public static void setFactory(SubscriptionMultipleFactory factory) {
        multipleFactory = factory;
    }

    @Override
    protected MultipleHandler createMultipleHandler() {
        return multipleFactory.createMultipleHandler();
    }

    @Override
    protected boolean requiresBody(String action) {
        return SubscriptionMultipleHandler.ACTIONS_REQUIRING_BODY.contains(action);
    }
    @Override
    protected boolean hasModulePermission(ServerSession session) {
        return session.getUserConfiguration().isSubscription();
    }


    @Override
    protected JSONObject modify(HttpServletRequest req, String action, JSONObject request) throws JSONException {
        request.put("__query", req.getQueryString());
        request.put("__serverURL", getServerURL(req));

        return request;
    }

    private String getServerURL(HttpServletRequest req) {
        String protocol = com.openexchange.tools.servlet.http.Tools.getProtocol(req);
        return protocol + req.getServerName();
    }

}

==> open-xchange-subscribe_7.4.1.orig.tar.bz2: open-xchange-subscribe-7.4.1/com.openexchange.subscribe.json/src/com/openexchange/subscribe/json/SubscriptionServlet.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.json;

import javax.servlet.http.HttpServletRequest;
import org.json.JSONException;
import org.json.JSONObject;
import com.openexchange.ajax.MultipleAdapterServlet;
import com.openexchange.multiple.MultipleHandler;
import com.openexchange.tools.session.ServerSession;


/**
 * {@link SubscriptionServlet}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class SubscriptionServlet extends MultipleAdapterServlet {

    private static final long serialVersionUID = -1033538285268622324L;

    private static SubscriptionMultipleFactory multipleFactory = null;

    public static void setFactory(SubscriptionMultipleFactory factory) {
        multipleFactory = factory;
    }

    @Override
    protected MultipleHandler createMultipleHandler() {
        return multipleFactory.createMultipleHandler();
    }

    @Override
    protected boolean requiresBody(String action) {
        return SubscriptionMultipleHandler.ACTIONS_REQUIRING_BODY.contains(action);
    }
    @Override
    protected boolean hasModulePermission(ServerSession session) {
        return session.getUserPermissionBits().isSubscription();
    }


    @Override
    protected JSONObject modify(HttpServletRequest req, String action, JSONObject request) throws JSONException {
        request.put("__query", req.getQueryString());
        request.put("__serverURL", getServerURL(req));

        return request;
    }

    private String getServerURL(HttpServletRequest req) {
        String protocol = com.openexchange.tools.servlet.http.Tools.getProtocol(req);
        return protocol + req.getServerName();
    }

}
